@@ -142,6 +142,9 @@ struct aws_credentials_provider_profile_options {
 
     /* For mocking the http layer in tests, leave NULL otherwise */
     struct aws_auth_http_system_vtable *function_table;
+
+    /* Add proxy options for sts based provider */
+    struct proxy_env_var_settings *proxy_ev_settings;
 };
 
 /**
